import React, { Component } from 'react';
import { TextField, Typography } from '@material-ui/core';
import * as R from 'ramda';
import api from '../../../api';
import Autocomplete from '@material-ui/lab/Autocomplete';
import { titleCase } from '../../../library/Utils';
import format from "date-fns/format";
import { DatePicker } from '@material-ui/pickers';
import Images from '../../../assets/Images';

export default class CreateReportItems extends Component {
    constructor(props) {
        super(props)
        this.state = {
            InputType: null,
            company: null,
            parent: null,
            reportType: null,
            startDate: null,
            endDate: null,
            order: null,
            description: '',
            uom: '',
            weight: null,
            formula: '',
            realVal: '',
            condition: null,
            date: new Date(),
            listInputType: null,
            listCompany: null,
            listReportType: null,
            listParent: null,
            errorOrder: false,
            errorDesc: false,
            errorFormula: false,
            errorRV: false,
            errorStartDate: false,
            errorEndDate: false,
            msgErrorOrder: '',
            msgErrorDesc: '',
            msgErrorFormula: '',
            msgErrorRV: '',
            msgErrorSD: '',
            msgErrorED: '',
            disabledFormula: true,
            disabledCondt: true,
            disabledValue: true,
            options: ['WARNING', 'STOPPER'] 

        }
    }

    componentDidMount() {
        this.getInputType()
        this.getPerusahaan()
        this.getReportType()
        // this.getParent()
    }


    handleChange(e, type) {
        let data = this.state
        let isDate = type !== ''? true : false
        if (isDate && type === 'start_date') {
            this.setState({...data, startDate: format(e, 'yyyy-MM-dd'), endDate: null,
                errorOrder: false,
                errorDesc: false,
                errorFormula: false,
                errorRV: false,
                errorStartDate: false,
                errorEndDate: false,
                msgErrorOrder: '',
                msgErrorDesc: '',
                msgErrorFormula: '',
                msgErrorRV: '',
                msgErrorSD: '',
                msgErrorED: '',
            })
        } else if (isDate && type === 'end_date') {
            this.setState({...data, endDate : format(e, 'yyyy-MM-dd'),
                errorOrder: false,
                errorDesc: false,
                errorFormula: false,
                errorRV: false,
                errorStartDate: false,
                errorEndDate: false,
                msgErrorOrder: '',
                msgErrorDesc: '',
                msgErrorFormula: '',
                msgErrorRV: '',
                msgErrorSD: '',
                msgErrorED: '',
            })
        } else {
            this.setState({...data, [e.target.name]:  e.target.value,
                errorOrder: false,
                errorDesc: false,
                errorFormula: false,
                errorRV: false,
                errorStartDate: false,
                errorEndDate: false,
                msgErrorOrder: '',
                msgErrorDesc: '',
                msgErrorFormula: '',
                msgErrorRV: '',
                msgErrorSD: '',
                msgErrorED: '',
            })
        }
    }

    validasi() {
        // alert('coba ya')
        if (R.isNil(this.state.reportType)) return alert("Jenis Laporan is Required.");
        if (R.isNil(this.state.company)) return alert("Perusahaan is Required.");
        else if (R.isEmpty(this.state.order)) {
            this.setState({errorOrder: true, msgErrorOrder: 'Order Harus Diisi'})
        } 
        else if (R.isEmpty(this.state.description)) {
            this.setState({errorDesc: true, msgErrorDesc: 'Deskripsi Harus Diisi'})
        } 
        else  if (R.isNil(this.state.InputType)) return alert("Tipe Data is Required.")
        else if (this.state.disabledFormula === false && R.isEmpty(this.state.formula)) {
            this.setState({errorFormula: true, msgErrorFormula: 'Formula Harus Diisi'})
        } 
        else if (this.state.disabledValue === false && R.isEmpty(this.state.realVal)) {
            this.setState({errorRV: true, msgErrorRV: 'Nilai Seharusnya Harus Diisi'})
        }
        else if (this.state.disabledCondt === false && R.isEmpty(this.state.condition)) return alert("Kondisi Jika Salah is Required.")
        else if (R.isNil(this.state.startDate)) {
            this.setState({errorStartDate: true, msgErrorSD: 'Start Date tidak boleh kosong'})
        } 
        else if (R.isNil(this.state.endDate)) {
            this.setState({errorEndDate: true, msgErrorED: 'End Date tidak boleh kosong'})
        } 
        else {
            this.addReportItems()
        }
    }

    addReportItems() {
        // alert("test")
        let payload = {
            "report_id": this.state.reportType.report_id,
            "company_id": this.state.company.company_id,
            "description": this.state.description,
            "orders": this.state.order,
            "parent": this.state.parent.item_report_id,
            "type_report_id": this.state.InputType.type_report_id,
            "formula": this.state.formula,
            "uom": this.state.uom,
            "weight": this.state.weight,
            "condition_if_wrong": this.state.condition,
            "condition_it_should_be": this.state.realVal,
            "start_date": this.state.startDate,
            "end_date": this.state.endDate
        }
        console.log(payload)
        api.create().createReportItems(payload).then((response) => {
            console.log(response)
            if (response.data.status === 'success') {
                this.props.onClickClose()
                this.props.refresh()
            } else {
                alert(response.data.message)
            }
        })
    }

    getInputType() {
        api.create().getInputType().then((response) => {
            console.log(response.data)
            if(response.data.status === 'success') {
                let data = response.data.data
                let inputData = data.map((item) => {
                    return {
                        type_report_id: item.type_report_id,
                        type_report_name: item.type_report_name
                    }
                })
                let defaultProps = {
                    options: inputData,
                    getOptionLabel: (option) => titleCase(option.type_report_name),
                  };
                this.setState({listInputType: defaultProps, inputData: response.data.data})
            } else {
                alert(response.data.message)
            }
        })
    }

    getPerusahaan() {
        api.create().getPerusahaanActive().then((response) => {
            // console.log(response)
            if(response.data.status === 'success') {
                let data = response.data.data
                let companyData = data.map((item) => {
                    return {
                        company_id: item.company_id,
                        company_name: item.company_name
                    }
                })
                let defaultProps = {
                    options: companyData,
                    getOptionLabel: (option) => titleCase(option.company_name),
                  };
                this.setState({listCompany: defaultProps, companyData: response.data.data})
            } else {
                alert(response.data.message)
            }
        })
    }

    getReportType() {
        api.create().getReportType().then((response) => {
            // console.log(response)
            if(response.data.status === 'success') {
                let data = response.data.data
                let reportTypeData = data.map((item) => {
                    return {
                        report_id: item.report_id,
                        report_name: item.report_name,
                    }
                })
                let defaultProps = {
                    options: reportTypeData,
                    getOptionLabel: (option) => titleCase(option.report_name),
                  };
                this.setState({listReportType: defaultProps, reportTypeData: response.data.data})
            } else {
                alert(response.data.message)
            }
        })
    }

    getParent() {
        if (this.state.reportType !== null && this.state.company !== null) { 
            let payload = {
                "report_id": this.state.reportType.report_id,
                "company_id": this.state.company.company_id
            }
            api.create().getReportParent(payload).then((response) => {
                console.log(response)
                if(response.data.status === 'success') {
                    let data = response.data.data
                    let parentData = data.map((item) => {
                        return {
                            item_report_id: item.item_report_id,
                            description: item.description
                        }
                    })
                    let defaultProps = {
                        options: parentData,
                        getOptionLabel: (option) => titleCase(option.description),
                      };
                    this.setState({listParent: defaultProps, parentData: response.data.data})
                } else {
                    alert(response.data.message)
                }
            })
        }
    }

    handleDate(item) {
        let value = format(item, 'dd MMMM yyyy')
        return value
    }

    render() {
        const { startDate, endDate } = this.state;

        return (
            <div className="test app-popup-show">
                <div className="popup-content background-white border-radius" style={{ borderRadius: 8 }}>
                    <div className="popup-panel grid grid-2x main-color" style={{ height: 64, borderTopRightRadius: 8, borderTopLeftRadius: 8 }}>
                        <div className="col-1" style={{ maxWidth: "inherit", display: 'flex', alignItems: 'center' }}>
                            <div className="popup-title">
                                <span style={{ color: '#fff', fontSize: 16, fontWeight: 'bold' }}>Tambah Data</span>
                            </div>
                        </div>
                        <div className="col-2 content-right" style={{ maxWidth: "inherit", alignSelf: 'center' }}>
                            <button
                                type="button"
                                className="btn btn-circle btn-white"
                                onClick={() => this.props.onClickClose()}
                            >
                                <img src={Images.close}/>
                            </button>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                            <div className="margin-top-10px" style={{ backgroundColor: '#e8e8e8', padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    value={'-'}
                                    id="ID"
                                    label="ID"
                                    disabled
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                />
                            </div>
                        </div>
                        <div className="column-2">
                            <div className="margin-top-10px" style={{padding: 10, borderRadius: 5}}>
                                <Autocomplete
                                    {...this.state.listReportType}
                                    id="reportType"
                                    onChange={(event, newInputValue) => this.setState({reportType: newInputValue})}
                                    debug
                                    renderInput={(params) => 
                                        <TextField {...params} 
                                            label="Jenis Laporan" 
                                            InputLabelProps={{
                                                style: {
                                                    fontSize: 11,
                                                    fontWeight: 600,
                                                    fontFamily: 'Nunito Sans, sans-serif',
                                                    color: '#7e8085'
                                                }
                                            }}
                                            InputProps={{ ...params.InputProps, style: { fontSize: 11, fontWeight: 600, fontFamily: 'Nunito Sans, sans-serif' } }}
                                        />}
                                    value={this.state.reportType}
                                />
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                            <div className="margin-top-10px" style={{padding: 10, borderRadius: 5}} >
                                <Autocomplete
                                    {...this.state.listCompany}
                                    id="company"
                                    onChange={(event, newInputValue) => this.setState({company: newInputValue}, () => this.getParent())}
                                    debug
                                    renderInput={(params) => 
                                        <TextField {...params} 
                                            label="Perusahaan" 
                                            InputLabelProps={{
                                                style: {
                                                    fontSize: 11,
                                                    fontWeight: 600,
                                                    fontFamily: 'Nunito Sans, sans-serif',
                                                    color: '#7e8085'
                                                }
                                            }}
                                            InputProps={{ ...params.InputProps, style: { fontSize: 11, fontWeight: 600, fontFamily: 'Nunito Sans, sans-serif' } }}
                                        />}
                                    value={this.state.company}
                                />
                            </div>
                        </div>
                        <div className="column-2">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    id="orders"
                                    name="order"
                                    label="Order"
                                    onChange={(e) => this.handleChange(e, '')}
                                    value={this.state.order}
                                    error={this.state.errorOrder}
                                    helperText={this.state.msgErrorOrder}
                                    onChange={(e) => this.handleChange(e, '')}
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                >
                                </TextField>
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    id="description"
                                    label="Deskripsi"
                                    name="description"
                                    value={this.state.description}
                                    error={this.state.errorDesc}
                                    helperText={this.state.msgErrorDesc}
                                    onChange={(e) => this.handleChange(e, '')}
                                    // value={this.props.data.business_unit_name}
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                >
                                </TextField>
                            </div>
                        </div>
                        <div className="column-2">
                        <div className="margin-top-10px" style={{padding: 10, borderRadius: 5}} >
                                <Autocomplete
                                    {...this.state.listParent}
                                    id="parentId"
                                    onChange={(event, newInputValue) => this.setState({parent: newInputValue})}
                                    debug
                                    disabled={this.state.reportType == null || this.state.company == null}
                                    renderInput={(params) => 
                                        <TextField {...params} 
                                            label="Parent ID" 
                                            InputLabelProps={{
                                                style: {
                                                    fontSize: 11,
                                                    fontWeight: 600,
                                                    fontFamily: 'Nunito Sans, sans-serif',
                                                    color: '#7e8085'
                                                }
                                            }}
                                            InputProps={{ ...params.InputProps, style: { fontSize: 11, fontWeight: 600, fontFamily: 'Nunito Sans, sans-serif' } }}
                                        />}
                                    value={this.state.parent}
                                />
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    id="uom"
                                    name="uom"
                                    label="UOM"
                                    value={this.state.uom}
                                    onChange={(e) => this.handleChange(e, '')}
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                >
                                </TextField>
                            </div>
                        </div>
                        <div className="column-2">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    id="weight"
                                    label="Weight"
                                    name="weight"
                                    value={this.state.weight}
                                    onChange={(e) => this.handleChange(e, '')}
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                >
                                </TextField>
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{padding: 10, borderRadius: 5}}>
                                <Autocomplete
                                    {...this.state.listInputType}
                                    id="inputType"
                                    onChange={(event, newInputValue) => this.setState({InputType: newInputValue}, 
                                        () => newInputValue === null ? this.setState({disabledFormula: true, disabledCondt: true, disabledValue: true, formula: '', condition: '', realVal: ''}) 
                                        : newInputValue.type_report_name === 'Formula' ? this.setState({disabledFormula: false, disabledCondt: true, disabledValue: true, formula: '', condition: '', realVal: ''}) 
                                        : newInputValue.type_report_name === 'Validation' ? this.setState({disabledFormula: false, disabledCondt: false, disabledValue: false, formula: '', condition: '', realVal: ''})
                                        : this.setState({disabledFormula: true, disabledCondt: true, disabledValue: true, formula: '', condition: '', realVal: ''})
                                        )}
                                    debug
                                    renderInput={(params) => 
                                        <TextField {...params} 
                                            label="Tipe Data" 
                                            InputLabelProps={{
                                                style: {
                                                    fontSize: 11,
                                                    fontWeight: 600,
                                                    fontFamily: 'Nunito Sans, sans-serif',
                                                    color: '#7e8085'
                                                }
                                            }}
                                            InputProps={{ ...params.InputProps, style: { fontSize: 11, fontWeight: 600, fontFamily: 'Nunito Sans, sans-serif' } }}
                                        />}
                                    value={this.state.InputType}
                                />
                            </div>
                        </div>
                        <div className="column-2">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    id="formula"
                                    label="Formula"
                                    name="formula"
                                    disabled={this.state.disabledFormula}
                                    value={this.state.formula}
                                    error={this.state.errorFormula}
                                    helperText={this.state.msgErrorFormula}
                                    onChange={(e) => this.handleChange(e, '')}
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                >
                                </TextField>
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{padding: 10, borderRadius: 5}}>
                                <TextField
                                    style={{ width: '100%' }}
                                    id="realVal"
                                    label="Nilai Seharusnya"
                                    name="realVal"
                                    disabled={this.state.disabledValue}
                                    value={this.state.realVal}
                                    error={this.state.errorRV}
                                    helperText={this.state.msgErrorRV}
                                    onChange={(e) => this.handleChange(e, '')}
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                />
                            </div>
                        </div>
                        <div className="column-2">
                        <div className="margin-top-10px" style={{padding: 10, borderRadius: 5}}>
                            <Autocomplete
                                    value={this.state.condition}
                                    id="isWrongCondition"
                                    disabled={this.state.disabledCondt}
                                    onChange={(event, newValue) => {
                                        this.setState({condition: newValue});
                                    }}
                                    options={this.state.options}
                                    renderInput={(params) => 
                                        <TextField {...params} 
                                            label="Kondisi Jika Salah" 
                                            InputLabelProps={{
                                                style: {
                                                    fontSize: 11,
                                                    fontWeight: 600,
                                                    fontFamily: 'Nunito Sans, sans-serif',
                                                    color: '#7e8085'
                                                }
                                            }}
                                            InputProps={{ ...params.InputProps, style: { fontSize: 11, fontWeight: 600, fontFamily: 'Nunito Sans, sans-serif' } }}
                                        />}
                                />
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                            <DatePicker
                                margin="normal"
                                id="startDate"
                                label="Berlaku Mulai"
                                format="dd MMMM yyyy"
                                value={this.state.startDate}
                                error={this.state.errorStartDate}
                                helperText={this.state.msgErrorSD}
                                onChange={(e) => this.handleChange(e, 'start_date')}
                                KeyboardButtonProps={{
                                    'aria-label': 'change date',
                                }}
                                inputProps={{
                                    style: {
                                        fontSize: 11,
                                        fontWeight: 600,
                                        fontFamily: 'Nunito Sans, sans-serif',
                                    }
                                }}
                                InputLabelProps={{
                                    style: {
                                        fontSize: 11,
                                        color: '#7e8085',
                                        fontWeight: 600,
                                        fontFamily: 'Nunito Sans, sans-serif',
                                    }
                                }}
                                
                                style={{padding: 0, margin: 0, width: '100%'}}
                                />
                            </div>
                        </div>
                        <div className="column-2">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                            <DatePicker
                                margin="normal"
                                id="endDate"
                                label="Berlaku Hingga"
                                format="dd MMMM yyyy"
                                value={this.state.endDate}
                                error={this.state.errorEndDate}
                                helperText={this.state.msgErrorED}
                                onChange={(e) => this.handleChange(e, 'end_date')}
                                minDate={this.state.startDate}
                                KeyboardButtonProps={{
                                    'aria-label': 'change date',
                                }}
                                inputProps={{
                                    style: {
                                        fontSize: 11,
                                        fontWeight: 600,
                                        fontFamily: 'Nunito Sans, sans-serif',
                                    }
                                }}
                                InputLabelProps={{
                                    style: {
                                        fontSize: 11,
                                        color: '#7e8085',
                                        fontWeight: 600,
                                        fontFamily: 'Nunito Sans, sans-serif',
                                    }
                                }}
                                
                                style={{padding: 0, margin: 0, width: '100%'}}
                                />
                            </div>
                        </div>
                    </div>

                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{ backgroundColor: '#e8e8e8', padding: 10, borderRadius: 5 }}>
                                <TextField
                                    style={{ width: '100%' }}
                                    value={'Aktif'}
                                    id="status"
                                    label="Status"
                                    disabled
                                    inputProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                        }
                                    }}
                                    InputLabelProps={{
                                        style: {
                                            fontSize: 11,
                                            fontWeight: 600,
                                            fontFamily: 'Nunito Sans, sans-serif',
                                            color: '#7e8085',
                                        }
                                    }}
                                />
                            </div>
                        </div>
                    </div>
                    
                    <div className="grid grid-2x grid-mobile-none gap-15px" style={{ paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1">
                        <div className="margin-top-10px" style={{ padding: 10, borderRadius: 5 }}>
                                <div style={{display: 'flex'}}>
                                    <Typography style={{ fontSize: 11, width: '20%' }}>Dibuat</Typography>
                                    <Typography style={{ fontSize: 11 }}>: Admin - 21 Jul 2020, 18:45</Typography>
                                </div>
                                <div style={{display: 'flex'}}>
                                    <Typography style={{ fontSize: 11, width: '20%' }}>Diubah</Typography>
                                    <Typography style={{ fontSize: 11 }}>: Admin - 21 Jul 2020, 18:45</Typography>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div className="border-top grid grid-2x" style={{ height: 56, backgroundColor: '#f5f5f5', paddingLeft: 20, paddingRight: 20 }}>
                        <div className="column-1" style={{ alignSelf: 'center' }}>
                            <button
                                type="button"
                                onClick={() => this.props.onClickClose()}
                            >
                                <div style={{ width: 102, height: 30, border: 'solid 1px #354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center' }}>
                                    <span style={{ color: '#354960', fontSize: 11 }}>Batal</span>
                                </div>
                            </button>
                        </div>
                        <div className="column-2" style={{display: 'flex', justifyContent: 'flex-end', alignItems: 'center'}}>
                        <button
                                type="button"
                                onClick={() => this.validasi()}
                            >
                                <div style={{ width: 102, height: 30, backgroundColor: '#354960', borderRadius: 5, alignItems: 'center', display: 'flex', justifyContent: 'center' }}>
                                    <span style={{ color: '#fff', fontSize: 11 }}>Simpan</span>
                                </div>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        )
    }
}
